@@ -23,11 +23,8 @@
 #include "kchatbaseitemdelegate.h"
 
 #include <klineedit.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
 #include <kconfig.h>
-#include <kdebug.h>
-#include <kglobal.h>
 #include <QLayout>
 #include <QComboBox>
 #include <QPixmap>
@@ -35,7 +32,7 @@
 #include <QApplication>
 #include <QListView>
 
-
+Q_LOGGING_CATEGORY(GAMES_BACKGAMMON, "games.backgammon")
 
 class KChatBasePrivate
 {
@@ -75,6 +72,10 @@ KChatBaseModel* KChatBase::model()
 
 KChatBase::KChatBase(QWidget* parent, KChatBaseModel* model, KChatBaseItemDelegate* delegate, bool noComboBox) : QFrame(parent)
 {
+  QLoggingCategory::setFilterRules(QLatin1Literal("games.lib.debug = true"));
+  QLoggingCategory::setFilterRules(QLatin1Literal("games.private.kgame.debug = true"));
+  QLoggingCategory::setFilterRules(QLatin1Literal("games.backgammon.debug = true"));
+  
   KChatBaseModel* mod = model;
   if (mod==0)
     mod = new KChatBaseModel(parent);
@@ -97,8 +98,7 @@ KChatBase::KChatBase(QWidget* parent, KChatBaseModel* model, KChatBaseItemDelega
  connect(d->mModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
           d->mBox, SLOT(scrollToBottom()));
 
- connect(d->mBox, SIGNAL(customContextMenuRequested(QPoint)),
-         this, SLOT(customMenuHandler(QPoint)));
+ connect(d->mBox, &QListView::customContextMenuRequested, this, &KChatBase::customMenuHandler);
 
  d->mBox->setContextMenuPolicy ( Qt::CustomContextMenu );
  d->mBox->setFocusPolicy(Qt::NoFocus);
@@ -112,8 +112,8 @@ KChatBase::KChatBase(QWidget* parent, KChatBaseModel* model, KChatBaseItemDelega
  d->mEdit->setHandleSignals(false);
  d->mEdit->setTrapReturnKey(true);
  d->mEdit->completionObject(); // add the completion object
- d->mEdit->setCompletionMode(KGlobalSettings::CompletionNone);
- connect(d->mEdit, SIGNAL(returnPressed(QString)), this, SLOT(slotReturnPressed(QString)));
+ d->mEdit->setCompletionMode(KCompletion::CompletionNone);
+ connect(d->mEdit, &KLineEdit::returnPressed, this, &KChatBase::slotReturnPressed);
  h->addWidget(d->mEdit);
 
  if (!noComboBox) {
@@ -135,12 +135,12 @@ const QModelIndex KChatBase::indexAt(const QPoint& pos) const
 
 void KChatBase::customMenuHandler(const QPoint &pos)
 {
-    kDebug(10500) << "custom menu has been requested at position="<<pos<<". Implement handler at subclass if you need it.";
+    qCDebug(GAMES_BACKGAMMON) << "custom menu has been requested at position="<<pos<<". Implement handler at subclass if you need it.";
 }
 
 KChatBase::~KChatBase()
 {
-// kDebug(11000) << "KChatBase: DESTRUCT (" << this << ")";
+// qCDebug(GAMES_LIB) << "KChatBase: DESTRUCT (" << this << ")";
  saveConfig();
  delete d;
 }
@@ -163,12 +163,12 @@ bool KChatBase::addSendingEntry(const QString& text, int id)
 bool KChatBase::insertSendingEntry(const QString& text, int id, int index)
 {
  if (!d->mCombo) {
-	kWarning(11000) << "KChatBase: Cannot add an entry to the combo box";
+	qCWarning(GAMES_LIB) << "KChatBase: Cannot add an entry to the combo box";
 	return false;
  }
  if (d->mIndex2Id.indexOf(id) != -1) {
-	kError(11000) << "KChatBase: Cannot add more than one entry with the same ID! ";
-	kError(11000) << "KChatBase: Text="<<text;
+	qCCritical(GAMES_LIB) << "KChatBase: Cannot add more than one entry with the same ID! ";
+	qCCritical(GAMES_LIB) << "KChatBase: Text="<<text;
 	return false;
  }
  d->mCombo->insertItem(index, text);
@@ -178,7 +178,7 @@ bool KChatBase::insertSendingEntry(const QString& text, int id, int index)
 	d->mIndex2Id.insert(d->mIndex2Id.at(index), id);
  }
  if (d->mIndex2Id.count() != d->mCombo->count()) {
-	kError(11000) << "KChatBase: internal ERROR - local IDs do not match combo box entries!";
+	qCCritical(GAMES_LIB) << "KChatBase: internal ERROR - local IDs do not match combo box entries!";
  }
  return true;
 }
@@ -186,21 +186,21 @@ bool KChatBase::insertSendingEntry(const QString& text, int id, int index)
 int KChatBase::sendingEntry() const
 {
  if (!d->mCombo) {
-	kWarning(11001) << "Cannot retrieve index from NULL combo box";
+	qCWarning(GAMES_PRIVATE_KGAME) << "Cannot retrieve index from NULL combo box";
 	return -1;
  }
  const int index = d->mCombo->currentIndex();
  if ( index >= 0 && index <  d->mIndex2Id.size())
     return d->mIndex2Id[index];
 
- kWarning(11000) << "could not find the selected sending entry!";
+ qCWarning(GAMES_LIB) << "could not find the selected sending entry!";
  return -1;
 }
 
 void KChatBase::removeSendingEntry(int id)
 {
  if (!d->mCombo) {
-	kWarning(11000) << "KChatBase: Cannot remove an entry from the combo box";
+	qCWarning(GAMES_LIB) << "KChatBase: Cannot remove an entry from the combo box";
 	return;
  }
  int idx = findIndex(id);
@@ -212,7 +212,7 @@ void KChatBase::removeSendingEntry(int id)
 void KChatBase::changeSendingEntry(const QString& text, int id)
 {
  if (!d->mCombo) {
-	kWarning(11000) << "KChatBase: Cannot change an entry in the combo box";
+	qCWarning(GAMES_LIB) << "KChatBase: Cannot change an entry in the combo box";
 	return;
  }
  int index = findIndex(id);
@@ -222,7 +222,7 @@ void KChatBase::changeSendingEntry(const QString& text, int id)
 void KChatBase::setSendingEntry(int id)
 {
  if (!d->mCombo) {
-	kWarning(11000) << "KChatBase: Cannot set an entry in the combo box";
+	qCWarning(GAMES_LIB) << "KChatBase: Cannot set an entry in the combo box";
 	return;
  }
  d->mCombo->setCurrentIndex(findIndex(id));
@@ -266,7 +266,7 @@ void KChatBase::slotClear()
 }
 
 
-void KChatBase::setCompletionMode(KGlobalSettings::Completion mode)
+void KChatBase::setCompletionMode(KCompletion::CompletionMode mode)
 { d->mEdit->setCompletionMode(mode); }
 
 void KChatBase::saveConfig(KConfig* conf)
@@ -368,4 +368,4 @@ void KChatBase::addSystemMessage(const QString& fromName, const QString& text)
    d->mModel->addSystemMessage(fromName, text);
 }
 
-#include "kchatbase.moc"
+
